==> enterprisemodules-wls_config-3.0.21.tar.gz: enterprisemodules-wls_config-3.0.21/meta/wls_jms_topic.py <==
username      = sys.argv[1]
password      = sys.argv[2]
url           = sys.argv[3]

connect(username, password, url)

execfile('/vagrant/files/wlst/common.py.erb')
execfile('/vagrant/meta/get_properties.py')

print 'base properties'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/UniformDistributedTopics/Topic1','wls_jms_topic')  # All default properties
print 'DeliveryFailureParams'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/UniformDistributedTopics/Topic1/DeliveryFailureParams/Topic1','wls_jms_topic', 'delivery_', 'DeliveryFailureParams/%{topic_name}/')  # All default properties
print 'DeliveryFailureParams'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/UniformDistributedTopics/Topic1/MessageLoggingParams/Topic1','wls_jms_topic', 'log_', 'MessageLoggingParams/%{topic_name}/')  # All default properties
print 'DeliveryFailureParams'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/UniformDistributedTopics/Topic1/DeliveryParamsOverrides/Topic1','wls_jms_topic', 'override_', 'DeliveryParamsOverrides/%{topic_name}/')  # All default properties
print 'Thresholds'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/UniformDistributedTopics/Topic1/Thresholds/Topic1','wls_jms_topic', 'thresholds_', 'Thresholds/%{topic_name}/')  # All default properties
print 'Multicast'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/UniformDistributedTopics/Topic1/Multicast/Topic1','wls_jms_topic', 'multicast_', 'Multicast/%{topic_name}/')  # All default properties

==> enterprisemodules-wls_config-3.1.0.tar.gz: enterprisemodules-wls_config-3.1.0/meta/wls_jms_topic.py <==
username      = sys.argv[1]
password      = sys.argv[2]
url           = sys.argv[3]

connect(username, password, url)

execfile('/etc/puppetlabs/code/environments/production/modules/wls_config//lib/puppet/provider/wls_config/wlst/templates/common.py.erb')
execfile('/etc/puppetlabs/code/environments/production/modules/wls_config/meta/get_properties.py')

print 'base properties'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/UniformDistributedTopics/Topic1','wls_jms_topic')  # All default properties
print 'DeliveryFailureParams'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/UniformDistributedTopics/Topic1/DeliveryFailureParams/Topic1','wls_jms_topic', 'delivery_', 'DeliveryFailureParams/%{topic_name}/')  # All default properties
print 'DeliveryFailureParams'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/UniformDistributedTopics/Topic1/MessageLoggingParams/Topic1','wls_jms_topic', 'log_', 'MessageLoggingParams/%{topic_name}/')  # All default properties
print 'DeliveryFailureParams'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/UniformDistributedTopics/Topic1/DeliveryParamsOverrides/Topic1','wls_jms_topic', 'override_', 'DeliveryParamsOverrides/%{topic_name}/')  # All default properties
print 'Thresholds'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/UniformDistributedTopics/Topic1/Thresholds/Topic1','wls_jms_topic', 'thresholds_', 'Thresholds/%{topic_name}/')  # All default properties
print 'Multicast'
properties('/JMSSystemResources/jmsClusterModule/JMSResource/jmsClusterModule/UniformDistributedTopics/Topic1/Multicast/Topic1','wls_jms_topic', 'multicast_', 'Multicast/%{topic_name}/')  # All default properties
